Python-Picnic-API
=================

Unofficial Python wrapper for the Picnic_ API. This API can be used to track upcoming deliveries and to check and manipulate your cart. Use the same credentials as you use for the app. 

This library is not affiliated with Picnic and retrieves data from the endpoints of the mobile application. Use at your own risk.

.. _Picnic: https://picnic.app/nl/